@@ -4,9 +4,9 @@ import requests
 from bs4 import BeautifulSoup as bs
 from youtube_scraping_api.constants import HEADERS, THUMBNAIL_TEMPLATE
 
-def searchDict(partial, key):
+def search_dict(partial, key):
     """Recursive search in dictionary
-    
+
     :param partial: Dictionary to search in
     :type partial: dict
     :param key: Key that you want to search in dictionary
@@ -19,14 +19,14 @@ def searchDict(partial, key):
             if k == key:
                 yield v
             else:
-                for o in searchDict(v, key):
+                for o in search_dict(v, key):
                     yield o
     elif isinstance(partial, list):
         for i in partial:
-            for o in searchDict(i, key):
+            for o in search_dict(i, key):
                 yield o
 
-def findSnippet(text, start, end, skip=(0, 0)):
+def find_snippet(text, start, end, skip=(0, 0)):
     """Find snippet in text
 
     :param text: Text to search in
@@ -41,11 +41,12 @@ def findSnippet(text, start, end, skip=(0, 0)):
     :rtype: str
     """
     start_index = text.find(start)
-    if start_index == -1: return start_index
+    if start_index == -1:
+        return start_index
     end = text.find(end, start_index)
-    return text[start_index+len(start)+skip[0]:end-skip[1]]
+    return text[start_index + len(start) + skip[0]:end - skip[1]]
 
-def parseContinuationToken(data):
+def parse_continuation_token(data):
     """Extract continuation from raw JSON data
 
     :param data: Raw JSON data
@@ -53,11 +54,11 @@ def parseContinuationToken(data):
     :return: Continuation token
     :rtype: str
     """
-    try: nextCT = next(searchDict(data, "token"))
+    try: nextCT = next(search_dict(data, "token"))
     except: nextCT = None
     finally: return nextCT
 
-def convertValidFilename(string):
+def convert_valid_filename(string):
     """Remove invalid character for saving file from string
 
     :param string: String to be converted into valid filename
@@ -68,7 +69,7 @@ def convertValidFilename(string):
     valid_chars = "-_.() %s%s" % (strlib.ascii_letters, strlib.digits)
     return "".join(c for c in string if c in valid_chars)
 
-def getInitialData(html): 
+def get_initial_data(html):
     """Extract primary JSON data from raw HTML source code
 
     :param html: Raw HTML source code
@@ -76,9 +77,9 @@ def getInitialData(html):
     :return: JSON data in form of dictionary
     :rtype: dict
     """
-    return json.loads(findSnippet(html, "var ytInitialData = ", "</script>", (0, 1)))
+    return json.loads(find_snippet(html, "var ytInitialData = ", "</script>", (0, 1)))
 
-def getInitialPlayerResponse(html):
+def get_initial_player_response(html):
     """Extract JSON data where video download links are located
 
     :param html: Raw HTML source code
@@ -86,9 +87,9 @@ def getInitialPlayerResponse(html):
     :return: JSON data in form of dictionary
     :rtype: dict
     """
-    return json.loads(findSnippet(html, "var ytInitialPlayerResponse = ", ";</script>", (0, 1))+"}", strict=False)
+    return json.loads(find_snippet(html, "var ytInitialPlayerResponse = ", ";</script>", (0, 1))+"}", strict=False)
 
-def revealRedirectUrl(url): 
+def reveal_redirect_url(url):
     """Get real url from redirect url
 
     :param url: Redirect url
@@ -98,7 +99,7 @@ def revealRedirectUrl(url):
     """
     return bs(requests.get(url, headers=HEADERS).content, "lxml").find("div", {"id": "redirect-action-container"}).find("a")["href"]
 
-def getThumbnail(videoId):
+def get_thumbnail(videoId):
     """Get url for thumbnails of video
 
     :param videoId: Youtube ID of the video
@@ -109,15 +110,15 @@ def getThumbnail(videoId):
     """
     return dict(map(lambda i: (i[0], i[1].format(videoId)), THUMBNAIL_TEMPLATE.items()))
 
-def getProxy():
+def get_proxy():
     proxies = requests.get('https://api.proxyscrape.com/v2/?request=getproxies&protocol=http&timeout=4550&country=all&ssl=all&anonymity=all&simplified=true').text.split('\r\n')
     for i in proxies:
         try:
             proxy = {
-                'http': 'http://'+i,
-                'https': 'http://'+i
+                'http': 'http://' + i,
+                'https': 'http://' + i
             }
             requests.get('https://youtube.com', proxies=proxy, timeout=5)
             return proxy
         except:
-            pass
\ No newline at end of file
+            pass
